//*****************************************************************************
//
// Title        : MP3stick - MP3 player
// Authors      : Michael Wolf
// File Name    : 'MP3stick.h'
// Date         : January 1, 2006
// Version      : 1.01
// Target MCU   : Atmel AVR ATmega128/1281
// Editor Tabs  : 2
//
// NOTE: The authors in no way will be responsible for damages that you
//       coul'd be using this code.
//       Use this code at your own risk.
//
//       This code is distributed under the GNU Public License
//       which can be found at http://www.gnu.org/licenses/gpl.txt
//
// Change Log
//
// Version  When        Who           What
// -------  ----        ---           ----
// 1.00     02/01/2006  Michael Wolf  Initial Release
// 1.01     12/08/2006  Michael Wolf  + Added define for auto power off time
//
//*****************************************************************************
#ifndef MP3STICK_H
#define MP3STICK_H

#define GCC_VERSION (__GNUC__ * 10000 + __GNUC_MINOR__ * 100 + __GNUC_PATCHLEVEL__)

#if(__AVR_LIBC_VERSION__ < 10400UL)
#warning Code was written for avr-libc v1.4.0 or higher
#endif

#if(GCC_VERSION < 30400)
#warning Code was written for GCC 3.4.0 or higher
#endif

#define TIMER1_START  0x0C	// Start value Timer1, Prescaler 256, CTC mode, OCR1A = Top
#define TIMER1_STOP   0x00	// Stop Timer1 value

// OCR1A Top value, 100ms interrupt
#define TICK_100MS    (uint16_t)(100000/(1000000UL/(MCU_XTAL/256)))

// auto power off time, default 60s
#define AUTO_OFF_TIME 600

// DO NOT  change the order of this enumeration, you will mess up the USART control
enum {
    STATE_IDLE = 0,
    STATE_PLAY,
    STATE_STOP,
    STATE_NEXT,
    STATE_PREV,
    STATE_NEXT_PL,
    STATE_PREV_PL,
    STATE_MENU,
    STATE_UP,
    STATE_DOWN,
    STATE_ENTER,
    STATE_GOSLEEP,
    // anything below is not accessable via serial control
    STATE_INIT, 
    STATE_BOOTLOAD 
};

void go_sleep (void);
void set_backlight (uint8_t duty);
uint8_t get_state (void);
void pump_audio (void);
uint8_t play_title (void);
void show_titleinfo (void);
void next_title (uint8_t dir);
uint16_t get_adcw (uint8_t chan);
uint16_t get_random (void);
void idle_task (void);
uint16_t browse_menu (void);
uint16_t browse_list (uint16_t index,
		      uint16_t min,
		      uint16_t max,
		      void (*disp_routine) (uint16_t));
void menu_disp (uint16_t index);
void show_stopscreen (void);

#endif // MP3STICK_H
