//*****************************************************************************
//
// Title        : MP3stick - MP3 player
// Authors      : Michael Wolf
// File Name    : 'hardware_conf.h'
// Date         : January 1, 2006
// Version      : 1.02
// Target MCU   : Atmel AVR ATmega128/1281
// Editor Tabs  : 2
//
// NOTE: The authors in no way will be responsible for damages that you
//       coul'd be using this code.
//       Use this code at your own risk.
//
//       This code is distributed under the GNU Public License
//       which can be found at http://www.gnu.org/licenses/gpl.txt
//
// Change Log
//
// Version  When        Who           What
// -------  ----        ---           ----
// 1.00     08/08/2006  Michael Wolf  Initial Release
// 1.02     21/08/2006  Michael Wolf  Added define for RC oscillator calibration
//
//*****************************************************************************
#ifndef HARDWARE_CONF_H
#define HARDWARE_CONF_H

#define RC_CALIB_VALUE  0xAC  // Calibration value for internal RC oscillator @ 8MHz
                              // use 0x7F as default value

// define battery voltages
#define PLAYER_OFF  3.00  // Volt
#define BATT_RED    3.20	// Volt
#define BATT_YELLOW 3.40	// Volt
#define BATT_GREEN  3.80	// Volt

// define hardware wiring
#define LCD_PORT      PORTC	// LCD Connection port
#define LCD_DIR       DDRC	// LCD Direction port
#define LCD_RST       PC5	// LCD Reset signal
#define LCD_CS        PC6	// LCD Chip Select signal

#define SPI_PORT      PORTB	// SPI Connection port
#define SPI_DIR       DDRB	// SPI Direction port
#define MISO          PB3	// SPI MISO signal
#define MOSI          PB2	// SPI MOSI signal
#define SCK           PB1	// SPI SCK signal
#define SS            PB0	// SPI SS signal

#define BL_PORT       PORTB	// Backlight Connection port
#define BL_DIR        DDRB	// Backlight Direction port
#define BL_SHDN       PB6	// LCD backlight shutdown output
#define BL_PWM        PB4 // LCD backlight PWM output

#define MMC_PORT      PORTC	// MMC Connection port
#define MMC_DIR       DDRC	// MMC Direction port
#define MMC_CS        PC7	// MMC card chip select signal

#define CARD_PORT     PORTA // Card detection/write protection Connection port
#define CARD_DIR      DDRA // Card detection/write protection Direction port
#define CARD_INP      PINA // Card detection/write protection Input port
#define CARD_DET      PA1 // Card detection pin
#define CARD_WP       PA0 // Card write protection pin

#define VS_PORT       PORTC	// VS1011 Connection port
#define VS_DIR        DDRC	// VS1001 Direction port
#define VS_BSYNC      PC2	// VS1011 BSYNC signal
#define VS_CS         PC1	// VS1011 Chip Select signal
#define VS_RESET      PC0	// VS1011 Reset signal

#define VS_DREQ_PORT  PORTE	// VS1011 DREQ Connection port
#define VS_DREQ_DIR   DDRE	// VS1011 DREQ Direction port
#define VS_DREQ_INP   PINE	// VS1011 DREQ Input port
#define VS_DREQ       PE4	// VS1011 Data Request signal

#define BATT_PORT     PORTD	// Battery Connection port
#define BATT_DIR      DDRD	// Battery Direction port
#define BATT_INP      PIND	// Battery Input port
#define BATT_CHG      PD7	// Battery charge signal input

#define KEY_PORT      PORTD	// Keys Connection port
#define KEY_DIR       DDRD	// Keys Direction port
#define KEY_INP       PIND	// Keys Input port
#define COMM_KEYS     PD5	// Common key signal
#define KEY4          PD4	// Key 4 signal
#define KEY3          PD3	// Key 3 signal
#define KEY2          PD2	// Key 2 signal
#define KEY1          PD1	// Key 1 signal
#define KEY5          PD0	// Key 5 = T signal

#define BATT_ADC_PORT PORTF	// Battery ADC Connection port
#define BATT_ADC_DIR  DDRF	// Battery ADC Direction port
#define BATT_ADC      PF7	// Battery voltage input signal
#define BATT_CHAN     7		// Battery voltage ADC channel

// Define VS1011_XTAL constant according to your VS1011 crystal frequency.
// Be sure your crystal is a ground wave type, NOT a third over tone type
//#define VS1011_XTAL   28000000UL // 28.000MHz 
//#define VS1011_XTAL   25000000UL // 25.000MHz
//#define VS1011_XTAL   24576000UL // 24.576Mhz
#define VS1011_XTAL	  24000000UL	// 24.000Mhz

// Uncomment this line for VS1011 crystal frequencys below 15MHz
//#define VS1011_USE_CLKDOUBLER

// calculate ADCW values for comparing
#define ADCW_PLAYER_OFF   (unsigned int)((PLAYER_OFF*1024)/4.40)
#define ADCW_BATT_RED     (unsigned int)((BATT_RED*1024)/4.40)
#define ADCW_BATT_YELLOW  (unsigned int)((BATT_YELLOW*1024)/4.40)
#define ADCW_BATT_GREEN   (unsigned int)((BATT_GREEN*1024)/4.40)

#endif // HARDWARE_CONF_H
