// *****************************************************************************
// 
// Title        : MP3stick - MP3 player
// Authors      : Michael Wolf
// File Name    : 'serial.c'
// Date         : January 4, 2006
// Version      : 1.00
// Target MCU   : Atmel AVR ATmega128/1281
// Editor Tabs  : 2
//
// NOTE: The authors in no way will be responsible for damages that you
//       coul'd be using this code.
//       Use this code at your own risk.
//
//       This code is distributed under the GNU Public License
//       which can be found at http://www.gnu.org/licenses/gpl.txt
//
// Change Log
//
// Version  When        Who           What
// -------  ----        ---           ----
// 1.00     02/01/2006  Michael Wolf  Initial Release
// 
// *****************************************************************************
#include <avr/io.h>
#include <stdint.h>
#include <stdio.h>

#include "firmware_conf.h"
#include "hardware_conf.h"
#include "serial.h"

#ifdef ENABLE_SERIAL
// *****************************************************************************
// Function: usart_init
// Parameters: none.
// Returns: none.
// 
// Description: Init USART0
// *****************************************************************************
void
usart_init (void)
{

    // enable pull-ups for USART pins
    PORTE |= _BV (PE1);
    PORTE |= _BV (PE0);

    UBRR0H = (((MCU_XTAL / BAUD_RATE) / 16) - 1) >> 8;	// set baud rate
    UBRR0L = (((MCU_XTAL / BAUD_RATE) / 16) - 1);
    UCSR0B = (1 << RXEN1) | (1 << TXEN1);	// enable Rx & Tx, enable
    // Rx interrupt
    UCSR0C = (1 << UCSZ11) | (1 << UCSZ10);	// config 8N1

};				// end usart_init
#endif

#ifdef ENABLE_SERIAL
// *****************************************************************************
// Function: usart_putc
// Parameters: Data byte to send
// Returns: none.
// 
// Description: Send one byte via USART0
// *****************************************************************************
extern int
usart_putchar (char data,
	       FILE * stream)
{
    while ((UCSR0A & _BV (UDRE0)) != _BV (UDRE0));
    UDR0 = data;
    return 0;
}
#endif

#ifdef ENABLE_SERIAL
// *****************************************************************************
// Function: usart_getchar
// Parameters: None.
// Returns: 0 = No character received
// else character received
// 
// Description: Receive one byte from USART0
// *****************************************************************************
extern uint8_t
usart_getchar (void)
{
    if ((UCSR0A & _BV (RXC0)) == _BV (RXC0))
        return UDR0;
    else
        return 0;
}
#endif
