//*****************************************************************************
//
// Title        : MP3stick - MP3 player
// Authors      : Michael Wolf
// File Name    : 'skin.c'
// Date         : June 15, 2006
// Version      : 1.02
// Target MCU   : Atmel AVR ATmega128/1281
// Editor Tabs  : 2
//
// NOTE: The authors in no way will be responsible for damages that you
//       coul'd be using this code.
//       Use this code at your own risk.
//
//       This code is distributed under the GNU Public License
//       which can be found at http://www.gnu.org/licenses/gpl.txt
//
// Change Log
//
// Version  When        Who           What
// -------  ----        ---           ----
// 1.00     15/06/2006  Michael Wolf  Initial Release
// 1.01     29/10/2006  Michael Wolf  Fixed cluster look-up for images for
//                                    fragmented skin files.
// 1.02     05/11/2006  Michael Wolf  Reworked code to support new FAT functions
//
//*****************************************************************************
#include <avr/io.h>
#include <stdint.h>
#include <stdio.h>
#include <stdlib.h>

#include "firmware_conf.h"
#include "hardware_conf.h"
#include "skin.h"
#include "fat.h"
#include "glcd.h"

//uint8_t skin_buffer[512];
FAT_FILE skin_file;
uint8_t number_of_skins = 0;
char skin_colors[36];

//*****************************************************************************
// Function: skin_init
// Parameters: Number of skin file to use, first file found = 0
// Returns: None
//
// Description: Open skin file on card
//*****************************************************************************
void
skin_init (uint8_t skin_num)
{

    if(fat_open (-1, "skin.skn", NULL, &skin_file) == S_OK)
        number_of_skins = 1;
    else
        number_of_skins = 0;
}

//*****************************************************************************
// Function: skin_image
// Parameters: Number of image to show, first image in file = 0
// Returns: None.
//
// Description: Show an image from skin file on LCD. Assumed image size is
//              128x128 pixel and data size 128x128 Bytes.
//              The given image number is used to calculate the offset within
//              file.
//*****************************************************************************
void
skin_image (uint8_t img_num)
{

    uint16_t bytes_read;

    fat_seek (&skin_file, (img_num * SKIN_IMAGE_SIZE), SEEK_START);

    lcd_window (2, 2, 129, 129);	// set LCD window size
    lcd_gotoxy (0, 0);
    lcd_sendcmd (LCD_CMD_RAMWR);	// write LCD memory

    // read number of sectors in accordeance with image size
    for (uint8_t i = 0; i < SKIN_IMAGE_SIZE / 512; i++) {
        // read one sector
        bytes_read = fat_read (sector_buffer, 512, &skin_file);

        // send data to LCD
        for (uint16_t j = 0; j < bytes_read; j++) {
            lcd_senddata (sector_buffer[j]);
        }
    }
}


//*****************************************************************************
// Function: skin_read_colors
// Parameters: None.
// Returns: None.
//
// Description: Read color definitions from skin file.
//              See skin definition for details.
//*****************************************************************************
void
skin_read_colors (void)
{

    fat_seek (&skin_file, (SKIN_IMAGE_COUNT * SKIN_IMAGE_SIZE), SEEK_START);
    if (number_of_skins)
        fat_read (skin_colors, sizeof (skin_colors), &skin_file);
}
